% This m-script calculates the test statistic for the multiple testing of
% multiple equilibria in de Paula and Tang (2011).
% The input is an N-by-I data matrix
function [T, Var, Stdev] = CalT(D);
N     = size(D,1);
D1    = [ones(N,1), D, D(:,1).*D(:,2), D(:,1).*D(:,3), D(:,2).*D(:,3)];
SIG   = D1'*D1./N - mean(D1,1)'*mean(D1,1);
mu0b  = mean(D1(:,1)); mu1b = mean(D1(:,2)); mu2b = mean(D1(:,3)); mu3b = mean(D1(:,4));
mu12b = mean(D1(:,5)); mu13b = mean(D1(:,6)); mu23b = mean(D1(:,7));
V1    = [2*mu1b*mu2b*mu0b^(-3)-mu12b*mu0b^(-2) + 2*mu1b*mu3b*mu0b^(-3)-mu13b*mu0b^(-2) ;...
         2*mu2b*mu3b*mu0b^(-3)-mu23b*mu0b^(-2) + 2*mu2b*mu1b*mu0b^(-3)-mu12b*mu0b^(-2) ;...
         2*mu3b*mu1b*mu0b^(-3)-mu13b*mu0b^(-2) + 2*mu3b*mu2b*mu0b^(-3)-mu23b*mu0b^(-2) ];
V2    = -mu0b^(-2)*[mu2b+mu3b, mu1b, mu1b; mu2b, mu1b+mu3b, mu2b; mu3b, mu3b, (mu1b+mu2b)];
V3    = [1/mu0b, 1/mu0b, 0; 1/mu0b, 0, 1/mu0b; 0, 1/mu0b, 1/mu0b];
V     = [V1,V2,V3];
T     = [ mu12b/mu0b + mu13b/mu0b - (mu1b/mu0b)*(mu2b/mu0b) - (mu1b/mu0b)*(mu3b/mu0b); ...
                  mu12b/mu0b + mu23b/mu0b - (mu1b/mu0b)*(mu2b/mu0b) - (mu2b/mu0b)*(mu3b/mu0b); ...
                  mu13b/mu0b + mu23b/mu0b - (mu1b/mu0b)*(mu3b/mu0b) - (mu2b/mu0b)*(mu3b/mu0b)];
Var   = V*SIG*V'; 
Stdev = diag(Var).^.5;
